==> rc-ui-lib-2.0.4.tgz: package/lib/lazyload/LazyloadImage.js <==
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __objRest = (source, exclude) => {
  var target = {};
  for (var prop in source)
    if (__hasOwnProp.call(source, prop) && exclude.indexOf(prop) < 0)
      target[prop] = source[prop];
  if (source != null && __getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(source)) {
      if (exclude.indexOf(prop) < 0 && __propIsEnum.call(source, prop))
        target[prop] = source[prop];
    }
  return target;
};
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var stdin_exports = {};
__export(stdin_exports, {
  default: () => stdin_default
});
module.exports = __toCommonJS(stdin_exports);
var import_react = __toESM(require("react"));
var import_LazyloadImageEvent = __toESM(require("./LazyloadImageEvent"));
var import_LazyloadImageObserve = __toESM(require("./LazyloadImageObserve"));
var import_utils = require("./utils");
const Lazyload = (props) => {
  const [mode, setMode] = (0, import_react.useState)("observer");
  const _a = props, {
    observer
  } = _a, resetProps = __objRest(_a, [
    "observer"
  ]);
  (0, import_react.useEffect)(() => {
    const toSetMode = (value) => {
      if (!import_utils.hasIntersectionObserver && value === import_utils.modeType.observer) {
        value = import_utils.modeType.event;
      }
      setMode(value);
    };
    toSetMode(observer ? import_utils.modeType.observer : import_utils.modeType.event);
  }, [observer]);
  return /* @__PURE__ */ import_react.default.createElement(import_react.default.Fragment, null, mode === import_utils.modeType.event ? /* @__PURE__ */ import_react.default.createElement(import_LazyloadImageEvent.default, resetProps) : /* @__PURE__ */ import_react.default.createElement(import_LazyloadImageObserve.default, resetProps));
};
Lazyload.defaultProps = {
  loading: null,
  observer: true,
  eventOptions: {
    scrollContainer: document.body,
    offset: 0,
    debounce: 300,
    throttle: 0,
    listenEvents: import_utils.DEFAULT_EVENTS
  }
};
var stdin_default = Lazyload;

==> rc-ui-lib-2.1.1.tgz: package/lib/lazyload/LazyloadImage.js <==
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __objRest = (source, exclude) => {
  var target = {};
  for (var prop in source)
    if (__hasOwnProp.call(source, prop) && exclude.indexOf(prop) < 0)
      target[prop] = source[prop];
  if (source != null && __getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(source)) {
      if (exclude.indexOf(prop) < 0 && __propIsEnum.call(source, prop))
        target[prop] = source[prop];
    }
  return target;
};
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var stdin_exports = {};
__export(stdin_exports, {
  default: () => stdin_default
});
module.exports = __toCommonJS(stdin_exports);
var import_react = __toESM(require("react"));
var import_LazyloadImageEvent = __toESM(require("./LazyloadImageEvent"));
var import_LazyloadImageObserve = __toESM(require("./LazyloadImageObserve"));
var import_utils = require("./utils");
const Lazyload = (props) => {
  const [mode, setMode] = (0, import_react.useState)();
  const _a = props, {
    observer
  } = _a, resetProps = __objRest(_a, [
    "observer"
  ]);
  (0, import_react.useEffect)(() => {
    const toSetMode = (value) => {
      if (!import_utils.hasIntersectionObserver && value === import_utils.modeType.observer) {
        value = import_utils.modeType.event;
      }
      setMode(value);
    };
    toSetMode(observer ? import_utils.modeType.observer : import_utils.modeType.event);
  }, [observer]);
  return /* @__PURE__ */ import_react.default.createElement(import_react.default.Fragment, null, mode === import_utils.modeType.event ? /* @__PURE__ */ import_react.default.createElement(import_LazyloadImageEvent.default, resetProps) : mode === import_utils.modeType.observer ? /* @__PURE__ */ import_react.default.createElement(import_LazyloadImageObserve.default, resetProps) : null);
};
Lazyload.defaultProps = {
  loading: null,
  observer: true,
  eventOptions: {
    scrollContainer: document.body,
    offset: 0,
    debounce: 300,
    throttle: 0,
    listenEvents: import_utils.DEFAULT_EVENTS
  }
};
var stdin_default = Lazyload;
